function Remove-WindowsApps {
  <#
  .SYNOPSIS
    Remove Windows Apps based on a list

  .DESCRIPTION
    Fully remove a list of Windows Apps, for new users or existing users profiles
      
  .PARAMETER AppName
    Name of application to remove, or list of application names to remove

  .EXAMPLE
    Remove-WindowsApps -AppName Microsoft.Getstarted

  .EXAMPLE
    Remove-WindowsApps -AppName @("Microsoft.Getstarted","Microsoft.People")

#>

  [CmdletBinding()]
  Param
  (
    [Parameter(Mandatory = $true)]
    [string[]]$AppName
  )

  Foreach ($app in $AppName) {
    # remove from provisionned application list
    try {
      $winApp = Get-ProvisionedAppxPackage -Online | Where-Object {$_.DisplayName -eq $app}
      if ($null -ne $winApp) {
        Remove-ProvisionedAppxPackage -Online -PackageName $winApp.PackageName -ErrorAction Stop | Out-Null
        Write-Host "$app - Windows Provisioned Application removed" 
      }
      else {
        Write-Host "$app - not found" 
      }
    } 
    catch {
      $err = $_.Exception.Message
      Write-Host "Error while removing '$app' Windows Provisioned Application" 
      Write-Host $err
    }
    # remove package for users already connected to the computer
    try {
      $winPkg = Get-AppxPackage -AllUsers $app 
      if ($null -ne $winPkg) {
        Remove-AppxPackage -Package $winPkg -AllUsers -ErrorAction Stop | Out-Null
        Write-Host "$app - Windows Application removed"
      }
      else {
        Write-Host "$app - Appx Package not found" 
      }
    }
    catch {
      $err = $_.Exception.Message
      Write-Host "Error while removing '$app' Windows Application"
      Write-Host $err
    }
  }
}
